tmf

package
v0.0.0-...-42cee99 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AttachmentResp

type AttachmentResp struct {
	// The preSigned url the
	PreSignedUrl *string `json:"preSignedUrl,omitempty"`
}

AttachmentResp struct for AttachmentResp

func NewAttachmentResp

func NewAttachmentResp() *AttachmentResp

NewAttachmentResp instantiates a new AttachmentResp object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewAttachmentRespWithDefaults

func NewAttachmentRespWithDefaults() *AttachmentResp

NewAttachmentRespWithDefaults instantiates a new AttachmentResp object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*AttachmentResp) GetPreSignedUrl

func (o *AttachmentResp) GetPreSignedUrl() string

GetPreSignedUrl returns the PreSignedUrl field value if set, zero value otherwise.

func (*AttachmentResp) GetPreSignedUrlOk

func (o *AttachmentResp) GetPreSignedUrlOk() (*string, bool)

GetPreSignedUrlOk returns a tuple with the PreSignedUrl field value if set, nil otherwise and a boolean to check if the value has been set.

func (*AttachmentResp) HasPreSignedUrl

func (o *AttachmentResp) HasPreSignedUrl() bool

HasPreSignedUrl returns a boolean if a field has been set.

func (AttachmentResp) MarshalJSON

func (o AttachmentResp) MarshalJSON() ([]byte, error)

func (*AttachmentResp) SetPreSignedUrl

func (o *AttachmentResp) SetPreSignedUrl(v string)

SetPreSignedUrl gets a reference to the given string and assigns it to the PreSignedUrl field.

type Document

type Document struct {
	// Name of the document type
	Type *string `json:"type,omitempty"`
	// A string used to give a name to the document
	Name *string `json:"name,omitempty"`
}

Document This is a document resource allowing meta-data and the information of the document model.

func NewDocument

func NewDocument() *Document

NewDocument instantiates a new Document object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewDocumentWithDefaults

func NewDocumentWithDefaults() *Document

NewDocumentWithDefaults instantiates a new Document object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*Document) GetName

func (o *Document) GetName() string

GetName returns the Name field value if set, zero value otherwise.

func (*Document) GetNameOk

func (o *Document) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value if set, nil otherwise and a boolean to check if the value has been set.

func (*Document) GetType

func (o *Document) GetType() string

GetType returns the Type field value if set, zero value otherwise.

func (*Document) GetTypeOk

func (o *Document) GetTypeOk() (*string, bool)

GetTypeOk returns a tuple with the Type field value if set, nil otherwise and a boolean to check if the value has been set.

func (*Document) HasName

func (o *Document) HasName() bool

HasName returns a boolean if a field has been set.

func (*Document) HasType

func (o *Document) HasType() bool

HasType returns a boolean if a field has been set.

func (Document) MarshalJSON

func (o Document) MarshalJSON() ([]byte, error)

func (*Document) SetName

func (o *Document) SetName(v string)

SetName gets a reference to the given string and assigns it to the Name field.

func (*Document) SetType

func (o *Document) SetType(v string)

SetType gets a reference to the given string and assigns it to the Type field.

type DocumentCreate

type DocumentCreate struct {
	// Name of the document type
	Type *string `json:"type,omitempty"`
	// A string used to give a name to the document
	Name *string `json:"name,omitempty"`
}

DocumentCreate This is the document resource when creating new documents

func NewDocumentCreate

func NewDocumentCreate() *DocumentCreate

NewDocumentCreate instantiates a new DocumentCreate object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewDocumentCreateWithDefaults

func NewDocumentCreateWithDefaults() *DocumentCreate

NewDocumentCreateWithDefaults instantiates a new DocumentCreate object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*DocumentCreate) GetName

func (o *DocumentCreate) GetName() string

GetName returns the Name field value if set, zero value otherwise.

func (*DocumentCreate) GetNameOk

func (o *DocumentCreate) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentCreate) GetType

func (o *DocumentCreate) GetType() string

GetType returns the Type field value if set, zero value otherwise.

func (*DocumentCreate) GetTypeOk

func (o *DocumentCreate) GetTypeOk() (*string, bool)

GetTypeOk returns a tuple with the Type field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentCreate) HasName

func (o *DocumentCreate) HasName() bool

HasName returns a boolean if a field has been set.

func (*DocumentCreate) HasType

func (o *DocumentCreate) HasType() bool

HasType returns a boolean if a field has been set.

func (DocumentCreate) MarshalJSON

func (o DocumentCreate) MarshalJSON() ([]byte, error)

func (*DocumentCreate) SetName

func (o *DocumentCreate) SetName(v string)

SetName gets a reference to the given string and assigns it to the Name field.

func (*DocumentCreate) SetType

func (o *DocumentCreate) SetType(v string)

SetType gets a reference to the given string and assigns it to the Type field.

type DocumentResp

type DocumentResp struct {
	Links *Links `json:"_links,omitempty"`
	// Identifier of the document.
	Id string `json:"id"`
	// The lifecycleState of the document, such as Active.
	LifecycleState string `json:"lifecycleState"`
	// The date and time the document was created.
	CreationDate *time.Time `json:"creationDate,omitempty"`
	// Name of the document type
	Type *string `json:"type,omitempty"`
	// A string used to give a name to the document
	Name *string `json:"name,omitempty"`
}

DocumentResp This is a document resource allowing meta-data and the information of the document model.

func NewDocumentResp

func NewDocumentResp(id string, lifecycleState string) *DocumentResp

NewDocumentResp instantiates a new DocumentResp object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewDocumentRespWithDefaults

func NewDocumentRespWithDefaults() *DocumentResp

NewDocumentRespWithDefaults instantiates a new DocumentResp object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*DocumentResp) GetCreationDate

func (o *DocumentResp) GetCreationDate() time.Time

GetCreationDate returns the CreationDate field value if set, zero value otherwise.

func (*DocumentResp) GetCreationDateOk

func (o *DocumentResp) GetCreationDateOk() (*time.Time, bool)

GetCreationDateOk returns a tuple with the CreationDate field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentResp) GetId

func (o *DocumentResp) GetId() string

GetId returns the Id field value

func (*DocumentResp) GetIdOk

func (o *DocumentResp) GetIdOk() (*string, bool)

GetIdOk returns a tuple with the Id field value and a boolean to check if the value has been set.

func (*DocumentResp) GetLifecycleState

func (o *DocumentResp) GetLifecycleState() string

GetLifecycleState returns the LifecycleState field value

func (*DocumentResp) GetLifecycleStateOk

func (o *DocumentResp) GetLifecycleStateOk() (*string, bool)

GetLifecycleStateOk returns a tuple with the LifecycleState field value and a boolean to check if the value has been set.

func (o *DocumentResp) GetLinks() Links

GetLinks returns the Links field value if set, zero value otherwise.

func (*DocumentResp) GetLinksOk

func (o *DocumentResp) GetLinksOk() (*Links, bool)

GetLinksOk returns a tuple with the Links field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentResp) GetName

func (o *DocumentResp) GetName() string

GetName returns the Name field value if set, zero value otherwise.

func (*DocumentResp) GetNameOk

func (o *DocumentResp) GetNameOk() (*string, bool)

GetNameOk returns a tuple with the Name field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentResp) GetType

func (o *DocumentResp) GetType() string

GetType returns the Type field value if set, zero value otherwise.

func (*DocumentResp) GetTypeOk

func (o *DocumentResp) GetTypeOk() (*string, bool)

GetTypeOk returns a tuple with the Type field value if set, nil otherwise and a boolean to check if the value has been set.

func (*DocumentResp) HasCreationDate

func (o *DocumentResp) HasCreationDate() bool

HasCreationDate returns a boolean if a field has been set.

func (o *DocumentResp) HasLinks() bool

HasLinks returns a boolean if a field has been set.

func (*DocumentResp) HasName

func (o *DocumentResp) HasName() bool

HasName returns a boolean if a field has been set.

func (*DocumentResp) HasType

func (o *DocumentResp) HasType() bool

HasType returns a boolean if a field has been set.

func (DocumentResp) MarshalJSON

func (o DocumentResp) MarshalJSON() ([]byte, error)

func (*DocumentResp) SetCreationDate

func (o *DocumentResp) SetCreationDate(v time.Time)

SetCreationDate gets a reference to the given time.Time and assigns it to the CreationDate field.

func (*DocumentResp) SetId

func (o *DocumentResp) SetId(v string)

SetId sets field value

func (*DocumentResp) SetLifecycleState

func (o *DocumentResp) SetLifecycleState(v string)

SetLifecycleState sets field value

func (o *DocumentResp) SetLinks(v Links)

SetLinks gets a reference to the given Links and assigns it to the Links field.

func (*DocumentResp) SetName

func (o *DocumentResp) SetName(v string)

SetName gets a reference to the given string and assigns it to the Name field.

func (*DocumentResp) SetType

func (o *DocumentResp) SetType(v string)

SetType gets a reference to the given string and assigns it to the Type field.

type Error

type Error struct {
	// Application specific error code, defined in the API or a common list.
	Code string `json:"code"`
	// More details and corrective actions related to the error which can be shown to a client user.
	Message string `json:"message"`
}

Error Used when an API throws an Error, typically with a HTTP error response-code (4xx, 5xx).

func NewError

func NewError(code string, message string) *Error

NewError instantiates a new Error object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewErrorWithDefaults

func NewErrorWithDefaults() *Error

NewErrorWithDefaults instantiates a new Error object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*Error) GetCode

func (o *Error) GetCode() string

GetCode returns the Code field value

func (*Error) GetCodeOk

func (o *Error) GetCodeOk() (*string, bool)

GetCodeOk returns a tuple with the Code field value and a boolean to check if the value has been set.

func (*Error) GetMessage

func (o *Error) GetMessage() string

GetMessage returns the Message field value

func (*Error) GetMessageOk

func (o *Error) GetMessageOk() (*string, bool)

GetMessageOk returns a tuple with the Message field value and a boolean to check if the value has been set.

func (Error) MarshalJSON

func (o Error) MarshalJSON() ([]byte, error)

func (*Error) SetCode

func (o *Error) SetCode(v string)

SetCode sets field value

func (*Error) SetMessage

func (o *Error) SetMessage(v string)

SetMessage sets field value

type HALSelfLink struct {
	// URI reference to the resource itself.
	Href string `json:"href"`
}

HALSelfLink Hyperlink reference to the resource itself.

func NewHALSelfLink(href string) *HALSelfLink

NewHALSelfLink instantiates a new HALSelfLink object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewHALSelfLinkWithDefaults

func NewHALSelfLinkWithDefaults() *HALSelfLink

NewHALSelfLinkWithDefaults instantiates a new HALSelfLink object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*HALSelfLink) GetHref

func (o *HALSelfLink) GetHref() string

GetHref returns the Href field value

func (*HALSelfLink) GetHrefOk

func (o *HALSelfLink) GetHrefOk() (*string, bool)

GetHrefOk returns a tuple with the Href field value and a boolean to check if the value has been set.

func (HALSelfLink) MarshalJSON

func (o HALSelfLink) MarshalJSON() ([]byte, error)

func (*HALSelfLink) SetHref

func (o *HALSelfLink) SetHref(v string)

SetHref sets field value

type Links struct {
	Self *HALSelfLink `json:"self,omitempty"`
}

Links Link reference to the resource itself.

func NewLinks() *Links

NewLinks instantiates a new Links object This constructor will assign default values to properties that have it defined, and makes sure properties required by API are set, but the set of arguments will change when the set of required properties is changed

func NewLinksWithDefaults

func NewLinksWithDefaults() *Links

NewLinksWithDefaults instantiates a new Links object This constructor will only assign default values to properties that have it defined, but it doesn't guarantee that properties required by API are set

func (*Links) GetSelf

func (o *Links) GetSelf() HALSelfLink

GetSelf returns the Self field value if set, zero value otherwise.

func (*Links) GetSelfOk

func (o *Links) GetSelfOk() (*HALSelfLink, bool)

GetSelfOk returns a tuple with the Self field value if set, nil otherwise and a boolean to check if the value has been set.

func (*Links) HasSelf

func (o *Links) HasSelf() bool

HasSelf returns a boolean if a field has been set.

func (Links) MarshalJSON

func (o Links) MarshalJSON() ([]byte, error)

func (*Links) SetSelf

func (o *Links) SetSelf(v HALSelfLink)

SetSelf gets a reference to the given HALSelfLink and assigns it to the Self field.

type NullableAttachmentResp

type NullableAttachmentResp struct {
	// contains filtered or unexported fields
}

func NewNullableAttachmentResp

func NewNullableAttachmentResp(val *AttachmentResp) *NullableAttachmentResp

func (NullableAttachmentResp) Get

func (NullableAttachmentResp) IsSet

func (v NullableAttachmentResp) IsSet() bool

func (NullableAttachmentResp) MarshalJSON

func (v NullableAttachmentResp) MarshalJSON() ([]byte, error)

func (*NullableAttachmentResp) Set

func (*NullableAttachmentResp) UnmarshalJSON

func (v *NullableAttachmentResp) UnmarshalJSON(src []byte) error

func (*NullableAttachmentResp) Unset

func (v *NullableAttachmentResp) Unset()

type NullableDocument

type NullableDocument struct {
	// contains filtered or unexported fields
}

func NewNullableDocument

func NewNullableDocument(val *Document) *NullableDocument

func (NullableDocument) Get

func (v NullableDocument) Get() *Document

func (NullableDocument) IsSet

func (v NullableDocument) IsSet() bool

func (NullableDocument) MarshalJSON

func (v NullableDocument) MarshalJSON() ([]byte, error)

func (*NullableDocument) Set

func (v *NullableDocument) Set(val *Document)

func (*NullableDocument) UnmarshalJSON

func (v *NullableDocument) UnmarshalJSON(src []byte) error

func (*NullableDocument) Unset

func (v *NullableDocument) Unset()

type NullableDocumentCreate

type NullableDocumentCreate struct {
	// contains filtered or unexported fields
}

func NewNullableDocumentCreate

func NewNullableDocumentCreate(val *DocumentCreate) *NullableDocumentCreate

func (NullableDocumentCreate) Get

func (NullableDocumentCreate) IsSet

func (v NullableDocumentCreate) IsSet() bool

func (NullableDocumentCreate) MarshalJSON

func (v NullableDocumentCreate) MarshalJSON() ([]byte, error)

func (*NullableDocumentCreate) Set

func (*NullableDocumentCreate) UnmarshalJSON

func (v *NullableDocumentCreate) UnmarshalJSON(src []byte) error

func (*NullableDocumentCreate) Unset

func (v *NullableDocumentCreate) Unset()

type NullableDocumentResp

type NullableDocumentResp struct {
	// contains filtered or unexported fields
}

func NewNullableDocumentResp

func NewNullableDocumentResp(val *DocumentResp) *NullableDocumentResp

func (NullableDocumentResp) Get

func (NullableDocumentResp) IsSet

func (v NullableDocumentResp) IsSet() bool

func (NullableDocumentResp) MarshalJSON

func (v NullableDocumentResp) MarshalJSON() ([]byte, error)

func (*NullableDocumentResp) Set

func (v *NullableDocumentResp) Set(val *DocumentResp)

func (*NullableDocumentResp) UnmarshalJSON

func (v *NullableDocumentResp) UnmarshalJSON(src []byte) error

func (*NullableDocumentResp) Unset

func (v *NullableDocumentResp) Unset()

type NullableError

type NullableError struct {
	// contains filtered or unexported fields
}

func NewNullableError

func NewNullableError(val *Error) *NullableError

func (NullableError) Get

func (v NullableError) Get() *Error

func (NullableError) IsSet

func (v NullableError) IsSet() bool

func (NullableError) MarshalJSON

func (v NullableError) MarshalJSON() ([]byte, error)

func (*NullableError) Set

func (v *NullableError) Set(val *Error)

func (*NullableError) UnmarshalJSON

func (v *NullableError) UnmarshalJSON(src []byte) error

func (*NullableError) Unset

func (v *NullableError) Unset()
type NullableHALSelfLink struct {
	// contains filtered or unexported fields
}
func NewNullableHALSelfLink(val *HALSelfLink) *NullableHALSelfLink

func (NullableHALSelfLink) Get

func (NullableHALSelfLink) IsSet

func (v NullableHALSelfLink) IsSet() bool

func (NullableHALSelfLink) MarshalJSON

func (v NullableHALSelfLink) MarshalJSON() ([]byte, error)

func (*NullableHALSelfLink) Set

func (v *NullableHALSelfLink) Set(val *HALSelfLink)

func (*NullableHALSelfLink) UnmarshalJSON

func (v *NullableHALSelfLink) UnmarshalJSON(src []byte) error

func (*NullableHALSelfLink) Unset

func (v *NullableHALSelfLink) Unset()
type NullableLinks struct {
	// contains filtered or unexported fields
}
func NewNullableLinks(val *Links) *NullableLinks

func (NullableLinks) Get

func (v NullableLinks) Get() *Links

func (NullableLinks) IsSet

func (v NullableLinks) IsSet() bool

func (NullableLinks) MarshalJSON

func (v NullableLinks) MarshalJSON() ([]byte, error)

func (*NullableLinks) Set

func (v *NullableLinks) Set(val *Links)

func (*NullableLinks) UnmarshalJSON

func (v *NullableLinks) UnmarshalJSON(src []byte) error

func (*NullableLinks) Unset

func (v *NullableLinks) Unset()

Jump to